@@ -7,7 +7,7 @@ from snowflake.snowpark._internal.analyzer.expression import Expression
 
 
 class GroupingSet(Expression):
-    def __init__(self, group_by_exprs: List[Expression]):
+    def __init__(self, group_by_exprs: List[Expression]) -> None:
         super().__init__()
         self.group_by_exprs = group_by_exprs
         self.children = group_by_exprs
@@ -22,6 +22,6 @@ class Rollup(GroupingSet):
 
 
 class GroupingSetsExpression(Expression):
-    def __init__(self, args: List[List[Expression]]):
+    def __init__(self, args: List[List[Expression]]) -> None:
         super().__init__()
         self.args = args
