@@ -371,6 +371,8 @@ class SnowflakePlanBuilder:
             attribute_to_schema_string(attributes),
             replace=True,
             table_type="temporary",
+            use_scoped_temp_objects=self.session._use_scoped_temp_objects,
+            is_generated=True,
         )
         insert_stmt = batch_insert_into_statement(
             temp_table_name, [attr.name for attr in attributes]
@@ -617,10 +619,22 @@ class SnowflakePlanBuilder:
             None,
         )
 
-    def create_temp_table(self, name: str, child: SnowflakePlan) -> SnowflakePlan:
+    def create_temp_table(
+        self,
+        name: str,
+        child: SnowflakePlan,
+        *,
+        use_scoped_temp_objects: bool = False,
+        is_generated: bool = False,
+    ) -> SnowflakePlan:
         return self.build_from_multiple_queries(
             lambda x: self.create_table_and_insert(
-                self.session, name, child.schema_query, x
+                self.session,
+                name,
+                child.schema_query,
+                x,
+                use_scoped_temp_objects=use_scoped_temp_objects,
+                is_generated=is_generated,
             ),
             child,
             None,
@@ -629,13 +643,22 @@ class SnowflakePlanBuilder:
         )
 
     def create_table_and_insert(
-        self, session, name: str, schema_query: str, query: str
+        self,
+        session,
+        name: str,
+        schema_query: str,
+        query: str,
+        *,
+        use_scoped_temp_objects: bool = False,
+        is_generated: bool = False,
     ) -> List[str]:
         attributes = session._get_result_attributes(schema_query)
         create_table = create_table_statement(
             name,
             attribute_to_schema_string(attributes),
             table_type="temporary",
+            use_scoped_temp_objects=use_scoped_temp_objects,
+            is_generated=is_generated,
         )
 
         return [
@@ -675,42 +698,54 @@ class SnowflakePlanBuilder:
             self.session._conn._telemetry_client.send_copy_pattern_telemetry()
 
         if not copy_options:  # use select
-            temp_file_format_name = (
-                fully_qualified_schema
-                + "."
-                + random_name_for_temp_object(TempObjectType.FILE_FORMAT)
-            )
-            queries = [
-                Query(
-                    create_file_format_statement(
-                        temp_file_format_name,
-                        format,
-                        format_type_options,
-                        temp=True,
-                        if_not_exist=True,
-                    ),
-                    is_ddl_on_temp_object=True,
-                ),
+            queries: List[Query] = []
+            post_queries: List[Query] = []
+            use_temp_file_format: bool = "FORMAT_NAME" not in options
+            if use_temp_file_format:
+                format_name = (
+                    fully_qualified_schema
+                    + "."
+                    + random_name_for_temp_object(TempObjectType.FILE_FORMAT)
+                )
+                queries.append(
+                    Query(
+                        create_file_format_statement(
+                            format_name,
+                            format,
+                            format_type_options,
+                            temp=True,
+                            if_not_exist=True,
+                            use_scoped_temp_objects=self.session._use_scoped_temp_objects,
+                            is_generated=True,
+                        ),
+                        is_ddl_on_temp_object=True,
+                    )
+                )
+                post_queries.append(
+                    Query(
+                        drop_file_format_if_exists_statement(format_name),
+                        is_ddl_on_temp_object=True,
+                    )
+                )
+            else:
+                format_name = options["FORMAT_NAME"]
+
+            queries.append(
                 Query(
                     select_from_path_with_format_statement(
                         schema_cast_named(schema_to_cast)
                         if infer_schema
                         else schema_cast_seq(schema),
                         path,
-                        temp_file_format_name,
+                        format_name,
                         pattern,
                     )
-                ),
-            ]
+                )
+            )
             return SnowflakePlan(
                 queries,
                 schema_value_statement(schema),
-                [
-                    Query(
-                        drop_file_format_if_exists_statement(temp_file_format_name),
-                        is_ddl_on_temp_object=True,
-                    )
-                ],
+                post_queries,
                 {},
                 self.session,
                 None,
@@ -749,6 +784,8 @@ class SnowflakePlanBuilder:
                         attribute_to_schema_string(temp_table_schema),
                         replace=True,
                         table_type="temporary",
+                        use_scoped_temp_objects=self.session._use_scoped_temp_objects,
+                        is_generated=True,
                     ),
                     is_ddl_on_temp_object=True,
                 ),
@@ -812,7 +849,7 @@ class SnowflakePlanBuilder:
             table_name=table_name,
             file_path=path,
             files=files,
-            file_format=file_format,
+            file_format_type=file_format,
             format_type_options=format_type_options,
             copy_options=copy_options,
             pattern=pattern,
@@ -982,6 +1019,9 @@ class Query:
         )
         self.is_ddl_on_temp_object = is_ddl_on_temp_object
 
+    def __repr__(self) -> str:
+        return f"Query({self.sql}, {self.query_id_place_holder}, {self.is_ddl_on_temp_object})"
+
 
 class BatchInsertQuery(Query):
     def __init__(
