@@ -3,10 +3,13 @@
 # Copyright (c) 2012-2022 Snowflake Computing Inc. All rights reserved.
 #
 """Context module for Snowpark."""
-from snowflake.snowpark.session import Session, _get_active_session
+import snowflake.snowpark
+
+_use_scoped_temp_objects = True
+# TODO: consider moving it to __init__.py
 
 
-def get_active_session() -> Session:
+def get_active_session() -> "snowflake.snowpark.Session":
     """Returns the current active Snowpark session.
 
     Raises: SnowparkSessionException: If there is more than one active session or no active sessions.
@@ -14,4 +17,4 @@ def get_active_session() -> Session:
     Returns:
         A :class:`Session` object for the current session.
     """
-    return _get_active_session()
+    return snowflake.snowpark.session._get_active_session()
