@@ -12,7 +12,7 @@ from functools import reduce
 from logging import getLogger
 from threading import RLock
 from types import ModuleType
-from typing import Any, Dict, Iterable, List, Optional, Set, Tuple, Union
+from typing import Any, Dict, Iterable, List, Literal, Optional, Set, Tuple, Union
 
 import cloudpickle
 import pkg_resources
@@ -48,14 +48,16 @@ from snowflake.snowpark._internal.type_utils import (
 from snowflake.snowpark._internal.utils import (
     MODULE_NAME_TO_PACKAGE_NAME_MAP,
     STAGE_PREFIX,
+    SUPPORTED_TABLE_TYPES,
     PythonObjJSONEncoder,
     TempObjectType,
     calculate_checksum,
-    deprecate,
+    deprecated,
     get_connector_version,
     get_os_name,
     get_python_version,
     get_stage_file_prefix_length,
+    get_temp_type_for_object,
     get_version,
     is_in_stored_procedure,
     normalize_remote_file_or_dir,
@@ -64,9 +66,11 @@ from snowflake.snowpark._internal.utils import (
     unwrap_single_quote,
     unwrap_stage_location_single_quote,
     validate_object_name,
+    warning,
     zip_file_or_directory_to_stream,
 )
 from snowflake.snowpark.column import Column
+from snowflake.snowpark.context import _use_scoped_temp_objects
 from snowflake.snowpark.dataframe import DataFrame
 from snowflake.snowpark.dataframe_reader import DataFrameReader
 from snowflake.snowpark.file_operation import FileOperation
@@ -111,6 +115,9 @@ _logger = getLogger(__name__)
 
 _session_management_lock = RLock()
 _active_sessions: Set["Session"] = set()
+_PYTHON_SNOWPARK_USE_SCOPED_TEMP_OBJECTS_STRING = (
+    "PYTHON_SNOWPARK_USE_SCOPED_TEMP_OBJECTS"
+)
 
 
 def _get_active_session() -> Optional["Session"]:
@@ -246,6 +253,17 @@ class Session:
         self._plan_builder = SnowflakePlanBuilder(self)
         self._last_action_id = 0
         self._last_canceled_id = 0
+        # consider making _session_parameters check a helpful function
+        self._use_scoped_temp_objects = bool(
+            _use_scoped_temp_objects
+            and (
+                conn._conn._session_parameters.get(
+                    _PYTHON_SNOWPARK_USE_SCOPED_TEMP_OBJECTS_STRING, True
+                )
+                if conn._conn._session_parameters
+                else True
+            )
+        )
 
         self._file = FileOperation(self)
 
@@ -258,6 +276,13 @@ class Session:
     def __exit__(self, exc_type, exc_val, exc_tb):
         self.close()
 
+    def __str__(self):
+        return (
+            f"<{self.__class__.__module__}.{self.__class__.__name__}: account={self.get_current_account()}, "
+            f"role={self.get_current_role()}, database={self.get_current_database()}, "
+            f"schema={self.get_current_schema()}, warehouse={self.get_current_warehouse()}>"
+        )
+
     def _generate_new_action_id(self) -> int:
         self._last_action_id += 1
         return self._last_action_id
@@ -755,7 +780,7 @@ class Session:
                             package_name
                         ).version
                         if package_client_version not in package_req:
-                            logging.warning(
+                            _logger.warning(
                                 "The version of package %s in the local environment is %s, "
                                 "which does not fit the criteria for the requirement %s. "
                                 "Your UDF might not work when the package version is different "
@@ -765,7 +790,7 @@ class Session:
                                 package,
                             )
                     except pkg_resources.DistributionNotFound:
-                        logging.warning(
+                        _logger.warning(
                             "package %s is not installed in the local environment"
                             "Your UDF might not work when the package is installed "
                             "on the server but not on your local environment.",
@@ -914,7 +939,7 @@ class Session:
             self,
             TableFunctionRelation(func_expr),
         )
-        set_api_call_source(d, f"Session.table_function[{func_expr.func_name}]")
+        set_api_call_source(d, "Session.table_function")
         return d
 
     def sql(self, query: str) -> DataFrame:
@@ -967,7 +992,8 @@ class Session:
         )
         if not self._stage_created:
             self._run_query(
-                f"create temporary stage if not exists {qualified_stage_name}",
+                f"create {get_temp_type_for_object(self._use_scoped_temp_objects, True)} \
+                stage if not exists {qualified_stage_name}",
                 is_ddl_on_temp_object=True,
             )
             self._stage_created = True
@@ -988,6 +1014,7 @@ class Session:
         auto_create_table: bool = False,
         create_temp_table: bool = False,
         overwrite: bool = False,
+        table_type: Literal["", "temp", "temporary", "transient"] = "",
     ) -> Table:
         """Writes a pandas DataFrame to a table in Snowflake and returns a
         Snowpark :class:`DataFrame` object referring to the table where the
@@ -1013,17 +1040,21 @@ class Session:
                 would allow you to upload a particular pandas DataFrame successfully. If you don't like the auto created
                 table, you can always create your own table before calling this function. For example, auto-created
                 tables will store :class:`list`, :class:`tuple` and :class:`dict` as strings in a VARCHAR column.
-            create_temp_table: The to-be-created table will be temporary if this is set to ``True``.
+            create_temp_table: (Deprecated) The to-be-created table will be temporary if this is set to ``True``. Note
+                that to avoid breaking changes, currently when this is set to True, it overrides ``table_type``.
             overwrite: Default value is ``False`` and the Pandas DataFrame data is appended to the existing table. If set to ``True`` and if auto_create_table is also set to ``True``,
                 then it drops the table. If set to ``True`` and if auto_create_table is set to ``False``,
                 then it trunctates the table. Note that in both cases (when overwrite is set to ``True``) it will replace the existing
                 contents of the table with that of the passed in Pandas DataFrame.
+            table_type: The table type of table to be created. The supported values are: ``temp``, ``temporary``,
+                        and ``transient``. An empty string means to create a permanent table. Learn more about table
+                        types `here <https://docs.snowflake.com/en/user-guide/tables-temp-transient.html>`_.
 
         Example::
 
             >>> import pandas as pd
             >>> pandas_df = pd.DataFrame([(1, "Steve"), (2, "Bob")], columns=["id", "name"])
-            >>> snowpark_df = session.write_pandas(pandas_df, "write_pandas_table", auto_create_table=True, create_temp_table=True)
+            >>> snowpark_df = session.write_pandas(pandas_df, "write_pandas_table", auto_create_table=True, table_type="temp")
             >>> snowpark_df.to_pandas()
                id   name
             0   1  Steve
@@ -1043,12 +1074,31 @@ class Session:
                id  name
             0   1  Jane
 
+            >>> pandas_df4 = pd.DataFrame([(1, "Jane")], columns=["id", "name"])
+            >>> snowpark_df4 = session.write_pandas(pandas_df4, "write_pandas_transient_table", auto_create_table=True, table_type="transient")
+            >>> snowpark_df4.to_pandas()
+               id  name
+            0   1  Jane
+
         Note:
             Unless ``auto_create_table`` is ``True``, you must first create a table in
             Snowflake that the passed in pandas DataFrame can be written to. If
             your pandas DataFrame cannot be written to the specified table, an
             exception will be raised.
         """
+        if create_temp_table:
+            warning(
+                "write_pandas.create_temp_table",
+                "create_temp_table is deprecated. We still respect this parameter when it is True but "
+                'please consider using `table_type="temporary"` instead.',
+            )
+            table_type = "temporary"
+
+        if table_type and table_type.lower() not in SUPPORTED_TABLE_TYPES:
+            raise ValueError(
+                f"Unsupported table type. Expected table types: {SUPPORTED_TABLE_TYPES}"
+            )
+
         success = None  # forward declaration
         try:
             if quote_identifiers:
@@ -1075,8 +1125,8 @@ class Session:
                 parallel=parallel,
                 quote_identifiers=quote_identifiers,
                 auto_create_table=auto_create_table,
-                create_temp_table=create_temp_table,
                 overwrite=overwrite,
+                table_type=table_type,
             )
         except ProgrammingError as pe:
             if pe.msg.endswith("does not exist"):
@@ -1359,6 +1409,13 @@ class Session:
         set_api_call_source(df, "Session.range")
         return df
 
+    def get_current_account(self) -> Optional[str]:
+        """
+        Returns the name of the current account for the Python connector session attached
+        to this session.
+        """
+        return self._conn._get_current_parameter("account")
+
     def get_current_database(self) -> Optional[str]:
         """
         Returns the name of the current database for the Python connector session attached
@@ -1530,13 +1587,13 @@ class Session:
             else:
                 sql_args.append(to_sql(arg, infer_type(arg)))
         df = self.sql(f"CALL {sproc_name}({', '.join(sql_args)})")
-        set_api_call_source(df, f"Session.call[{sproc_name}]")
+        set_api_call_source(df, "Session.call")
         return df.collect()[0][0]
 
-    @deprecate(
-        deprecate_version="0.7.0",
-        extra_warning_text="`Session.flatten()` is deprecated. Use `Session.table_function()` instead.",
-        extra_doc_string="This method is deprecated. Use :meth:`table_function` instead.",
+    @deprecated(
+        version="0.7.0",
+        extra_warning_text="Use `Session.table_function()` instead.",
+        extra_doc_string="Use :meth:`table_function` instead.",
     )
     def flatten(
         self,
@@ -1630,8 +1687,41 @@ class Session:
         return query_listener
 
     def _table_exists(self, table_name: str):
-        # TODO: Support qualified table names
-        tables = self._run_query(f"show tables like '{table_name}'")
+        # implementation based upon: https://docs.snowflake.com/en/sql-reference/name-resolution.html
+        validate_object_name(table_name)
+        # note: object name could have dots, e.g, a table could be created via: create table "abc.abc" (id int)
+        # currently validate_object_name does not allow it, but if in the future we want to support the case, we need to
+        # update the implementation accordingly in this method
+        qualified_table_name = table_name.split(".")
+        if len(qualified_table_name) == 1:
+            # name in the form of "table"
+            tables = self._run_query(f"show tables like '{table_name}'")
+        elif len(qualified_table_name) == 2:
+            # name in the form of "schema.table" omitting database
+            # schema: qualified_table_name[0]
+            # table: qualified_table_name[1]
+            tables = self._run_query(
+                f"show tables like '{qualified_table_name[1]}' in schema {qualified_table_name[0]}"
+            )
+        elif len(qualified_table_name) == 3:
+            # name in the form of "database.schema.table"
+            # database: qualified_table_name[0]
+            # schema: qualified_table_name[1]
+            # table: qualified_table_name[2]
+            condition = (
+                f"database {qualified_table_name[0]}"
+                if qualified_table_name[1] == ""
+                else f"schema {qualified_table_name[0]}.{qualified_table_name[1]}"
+            )
+            tables = self._run_query(
+                f"show tables like '{qualified_table_name[2]}' in {condition}"
+            )
+        else:
+            # we do not support len(qualified_table_name) > 3 for now
+            raise SnowparkClientExceptionMessages.GENERAL_INVALID_OBJECT_NAME(
+                table_name
+            )
+
         return tables is not None and len(tables) > 0
 
     def _explain_query(self, query: str) -> Optional[str]:
