@@ -18,6 +18,7 @@ from snowflake.snowpark._internal.analyzer.table_merge_expression import (
 from snowflake.snowpark._internal.error_message import SnowparkClientExceptionMessages
 from snowflake.snowpark._internal.telemetry import add_api_call, set_api_call_source
 from snowflake.snowpark._internal.type_utils import ColumnOrLiteral
+from snowflake.snowpark._internal.utils import warning
 from snowflake.snowpark.column import Column
 from snowflake.snowpark.dataframe import DataFrame, _disambiguate
 from snowflake.snowpark.row import Row
@@ -320,7 +321,8 @@ class Table(DataFrame):
         source: Optional[DataFrame] = None,
         *,
         statement_params: Optional[Dict[str, str]] = None,
-    ) -> UpdateResult:
+        block: bool = True,
+    ) -> Union[UpdateResult, "snowflake.snowpark.AsyncJob"]:
         """
         Updates rows in the Table with specified ``assignments`` and returns a
         :class:`UpdateResult`, representing the number of rows modified and the
@@ -335,6 +337,9 @@ class Table(DataFrame):
             source: An optional :class:`DataFrame` that is included in ``condition``.
                 It can also be another :class:`Table`.
             statement_params: Dictionary of statement level parameters to be set while executing this action.
+            block: (Experimental) A bool value indicating whether this function will wait until the result is available.
+                When it is ``False``, this function executes the underlying queries of the dataframe
+                asynchronously and returns an :class:`AsyncJob`.
 
         Examples::
 
@@ -365,6 +370,12 @@ class Table(DataFrame):
             >>> t.collect()
             [Row(A=1, B=0), Row(A=1, B=0), Row(A=2, B=0), Row(A=2, B=0), Row(A=3, B=0), Row(A=3, B=0)]
         """
+        if not block:
+            warning(
+                "update.block",
+                "block argument is experimental. Do not use it in production.",
+            )
+
         if source:
             assert (
                 condition is not None
@@ -384,9 +395,12 @@ class Table(DataFrame):
             )
         )
         add_api_call(new_df, "Table.update")
-        return _get_update_result(
-            new_df._internal_collect_with_tag(statement_params=statement_params)
+        result = new_df._internal_collect_with_tag(
+            statement_params=statement_params,
+            block=block,
+            data_type=snowflake.snowpark.async_job._AsyncDataType.UPDATE,
         )
+        return _get_update_result(result) if block else result
 
     def delete(
         self,
@@ -394,7 +408,8 @@ class Table(DataFrame):
         source: Optional[DataFrame] = None,
         *,
         statement_params: Optional[Dict[str, str]] = None,
-    ) -> DeleteResult:
+        block: bool = True,
+    ) -> Union[DeleteResult, "snowflake.snowpark.AsyncJob"]:
         """
         Deletes rows in a Table and returns a :class:`DeleteResult`,
         representing the number of rows deleted.
@@ -405,6 +420,9 @@ class Table(DataFrame):
             source: An optional :class:`DataFrame` that is included in ``condition``.
                 It can also be another :class:`Table`.
             statement_params: Dictionary of statement level parameters to be set while executing this action.
+            block: (Experimental) A bool value indicating whether this function will wait until the result is available.
+                When it is ``False``, this function executes the underlying queries of the dataframe
+                asynchronously and returns an :class:`AsyncJob`.
 
         Examples::
 
@@ -434,6 +452,12 @@ class Table(DataFrame):
             >>> t.collect()
             [Row(A=1, B=1), Row(A=1, B=2)]
         """
+        if not block:
+            warning(
+                "delete.block",
+                "block argument is experimental. Do not use it in production.",
+            )
+
         if source:
             assert (
                 condition is not None
@@ -449,9 +473,12 @@ class Table(DataFrame):
             )
         )
         add_api_call(new_df, "Table.delete")
-        return _get_delete_result(
-            new_df._internal_collect_with_tag(statement_params=statement_params)
+        result = new_df._internal_collect_with_tag(
+            statement_params=statement_params,
+            block=block,
+            data_type=snowflake.snowpark.async_job._AsyncDataType.DELETE,
         )
+        return _get_delete_result(result) if block else result
 
     def merge(
         self,
@@ -460,7 +487,8 @@ class Table(DataFrame):
         clauses: Iterable[Union[WhenMatchedClause, WhenNotMatchedClause]],
         *,
         statement_params: Optional[Dict[str, str]] = None,
-    ) -> MergeResult:
+        block: bool = True,
+    ) -> Union[MergeResult, "snowflake.snowpark.AsyncJob"]:
         """
         Merges this :class:`Table` with :class:`DataFrame` source on the specified
         join expression and a list of matched or not-matched clauses, and returns
@@ -480,6 +508,9 @@ class Table(DataFrame):
                 of :class:`WhenMatchedClause` and :class:`WhenNotMatchedClause`, and will
                 be performed sequentially in this list.
             statement_params: Dictionary of statement level parameters to be set while executing this action.
+            block: (Experimental) A bool value indicating whether this function will wait until the result is available.
+                When it is ``False``, this function executes the underlying queries of the dataframe
+                asynchronously and returns an :class:`AsyncJob`.
 
         Example::
 
@@ -494,6 +525,12 @@ class Table(DataFrame):
             >>> target.collect()
             [Row(KEY=13, VALUE=None), Row(KEY=12, VALUE=None), Row(KEY=10, VALUE='new'), Row(KEY=10, VALUE='new'), Row(KEY=11, VALUE='old')]
         """
+        if not block:
+            warning(
+                "merge.block",
+                "block argument is experimental. Do not use it in production.",
+            )
+
         inserted, updated, deleted = False, False, False
         merge_exprs = []
         for c in clauses:
@@ -519,9 +556,22 @@ class Table(DataFrame):
             )
         )
         add_api_call(new_df, "Table.update")
-        return _get_merge_result(
-            new_df._internal_collect_with_tag(statement_params=statement_params),
-            inserted=inserted,
-            updated=updated,
-            deleted=deleted,
+        result = new_df._internal_collect_with_tag(
+            statement_params=statement_params,
+            block=block,
+            data_type=snowflake.snowpark.async_job._AsyncDataType.MERGE,
+        )
+        if not block:
+            result._inserted = inserted
+            result._updated = updated
+            result._deleted = deleted
+        return (
+            _get_merge_result(
+                result,
+                inserted=inserted,
+                updated=updated,
+                deleted=deleted,
+            )
+            if block
+            else result
         )
